@@ -4,7 +4,7 @@ from django.core.mail import send_mail
 from django.core.context_processors import csrf
 from indeed_contactForm.models import Message
 from indeed_contactForm.forms import ContactForm
-from django.conf.settings import EMAIL_CONTACT
+from django.conf import settings
 import datetime
 
 
@@ -20,8 +20,8 @@ def contact(request,  template, context={}):
                 cd['subject'],
                 cd['message'],
                 mail(cd['mail']),
-                EMAIL_CONTACT)
-            return HttpResponseRedirect('/contact')				# resend if f5?
+                settings.EMAIL_CONTACT)
+            return HttpResponseRedirect('/contact')
     else:
         form = ContactForm()
 
